@@ -1744,7 +1744,8 @@ void phi_gp_MH_sptp(double *Qeta1, double *Qeta2, double *det1, double *det2,
      else{    
      tr1 = (a-1.0)*log(phi1[0])-b*phi1[0]-0.5*rT1*log(det1[0])- u; 
      tr2 = (a-1.0)*log(phi2[0])-b*phi2[0]-0.5*rT1*log(det2[0])- v; 
-     ratio[0] = exp(tr2 + exp(tr2) - tr1 - exp(tr1));
+     ratio[0] = exp(tr2 - tr1 + log(phi2[0]) - log(phi1[0]));
+//     ratio[0] = exp(tr2 + exp(tr2) - tr1 - exp(tr1));
      ratio_fnc(ratio, constant, U);
      if(U[0] < ratio[0]){
           phip[0] = phi2[0];
